#[sim_site]Expand description
Marks a site export inside a #[sim_lib] module. The marker names the site
symbol plus the function called by generated native ABI dispatch for
realization requests.
#[sim_site]Marks a site export inside a #[sim_lib] module. The marker names the site
symbol plus the function called by generated native ABI dispatch for
realization requests.