Module classes

Module classes 

Native class authoring helpers: a Class implementation plus the lib wrapper that registers a host-defined class, its constructor, and members.

Structs

ClassInstance
Instance of a native class: its class symbol, the constructor arguments it was built from, and its field values.
MemberFunction
Callable that reads one field out of an instance of a native class.
NativeClass
Host-defined class: a constructor, optional shapes, parents, and members implementing the kernel Class and Callable contracts.
NativeClassLib
Lib that registers a host-defined NativeClass, its constructor, optional constructor and instance shapes, and its member functions.

Functions

constructor_function
Borrows the constructor function of a native class.