pub trait SearchInterrupt {
// Required method
fn is_cancelled(&self) -> bool;
}Expand description
Interrupt source checked by the search loop between bounded operations.
Required Methods
Sourcefn is_cancelled(&self) -> bool
fn is_cancelled(&self) -> bool
Return true when the caller wants the run to stop with a cancellation receipt.
Dyn Compatibility
This trait is dyn compatible.
In older versions of Rust, dyn compatibility was called "object safety".