pub enum BoundedSubclassOutcome {
Subclass(ClassMatchEvidence),
NotSubclass(ClassMatchEvidence),
InvalidClassGraph {
reason: String,
},
BudgetExhausted {
limit: usize,
performed_work: usize,
},
}Expand description
Exact result supplied by a bounded class-relation provider such as CLASS_2.
Variants
Subclass(ClassMatchEvidence)
Positive subclass evidence.
NotSubclass(ClassMatchEvidence)
Conclusive negative subclass evidence.
InvalidClassGraph
The provider rejected a malformed or cyclic parent graph.
BudgetExhausted
The provider could not decide within the supplied allowance.