pub fn function_case_result_shape(case: &FunctionCase) -> Option<&dyn Shape>Expand description
Returns the result shape of a function overload case, if it declares one.
pub fn function_case_result_shape(case: &FunctionCase) -> Option<&dyn Shape>Returns the result shape of a function overload case, if it declares one.