pub fn function_case_shape(case: &FunctionCase) -> &dyn ShapeExpand description
Returns the argument shape of a function overload case.
pub fn function_case_shape(case: &FunctionCase) -> &dyn ShapeReturns the argument shape of a function overload case.