pub enum ManagedAllocation {
Acyclic,
Cyclic,
}Expand description
Declares whether a guest profile allocates managed objects that may cycle.
Variants
Acyclic
The profile does not allocate managed cyclic graphs.
Cyclic
The profile may allocate reference cycles and therefore needs reclamation.