pub struct EdgeLimits { /* private fields */ }Expand description
Shared language-neutral arena, node, edge, and retention building blocks.
Hard limits for the outgoing edges owned by one ManagedNode.
Implementations
Sourceimpl EdgeLimits
impl EdgeLimits
Sourcepub const DEFAULT: EdgeLimits
pub const DEFAULT: EdgeLimits
Default per-node hard cap. Per-kind caps share the same ceiling while the total cap prevents their sum from exceeding it.