pub fn decode_binary_lib_pack(bytes: &[u8]) -> Result<BinaryLibPack>Expand description
Decodes a binary lib pack from its byte representation, validating the header.
pub fn decode_binary_lib_pack(bytes: &[u8]) -> Result<BinaryLibPack>Decodes a binary lib pack from its byte representation, validating the header.