pub fn standard_loader_registry() -> LoaderRegistryExpand description
Builds a loader registry with the standard loaders for the enabled features.
pub fn standard_loader_registry() -> LoaderRegistryBuilds a loader registry with the standard loaders for the enabled features.