pub struct LispSourceLoader { /* private fields */ }Expand description
Loader that compiles .lisp source files into libs using a Lisp codec.
Implementations
Sourceimpl LispSourceLoader
impl LispSourceLoader
Sourcepub fn new(codec: Symbol) -> LispSourceLoader
pub fn new(codec: Symbol) -> LispSourceLoader
Creates a loader that decodes source with the codec named codec.