pub fn macroexpand_function(
case_id: CaseId,
function_id: FunctionId,
symbol: Symbol,
) -> FunctionObjectExpand description
Builds the macroexpand function object that expands a quoted expression.
pub fn macroexpand_function(
case_id: CaseId,
function_id: FunctionId,
symbol: Symbol,
) -> FunctionObjectBuilds the macroexpand function object that expands a quoted expression.