pub enum DissonanceContext {
Passing,
Neighbor,
Suspension,
}Expand description
Recognized context in which a dissonant class may be accepted.
Variants
Passing
Stepwise motion continues in the same direction.
Neighbor
Stepwise motion leaves and returns to the same pitch.
Suspension
A prepared held note resolves downward by step.