pub struct AlignmentWindow {
pub span: TimeSpan,
pub notes: Vec<NoteEvidence>,
}Expand description
A maximal exact interval with an unchanging set of sounding notes.
Fields
span: TimeSpanExact half-open window.
notes: Vec<NoteEvidence>Notes sounding throughout the window, in deterministic voice order.