pub struct MotionRules {
pub forbid_parallel_perfects: bool,
pub forbid_direct_perfects: bool,
pub leap_threshold: u8,
}Expand description
Relative-motion policy.
Fields
forbid_parallel_perfects: boolReject similar motion between repeated perfect interval classes.
forbid_direct_perfects: boolReject similar motion into a perfect interval when either voice leaps.
leap_threshold: u8Semitone distance above which a voice movement is a leap.