Module cookbook_directory

Module cookbook_directory 

sim-nest’s product cookbook loadable-lib directory.

sim-lib-cookbook keeps a small standalone fixture directory. The umbrella crate owns the product directory because only this crate sees the constellation feature graph without adding back-edges to the cookbook lib.

Structs

SimNestCookbookResolver
Resolver over the loadable libs linked into this sim-nest build.

Functions

cookbook_all_lib_ids
Loadable-lib ids compiled into a cookbook-all build.
default_cookbook_config
Product default cookbook config for the enabled sim-nest feature set.
default_loadable_libs
Resolve the product default directory for the enabled sim-nest feature set.