pub fn prove_consent_without_kernel_grant(cx: &Cx) -> ConsentProofExpand description
Runs the consent and retention portions that do not need test-only grants.
pub fn prove_consent_without_kernel_grant(cx: &Cx) -> ConsentProofRuns the consent and retention portions that do not need test-only grants.