pub fn prove_retention_reaper(receipt: &ConsentReceipt) -> RetentionProofExpand description
Runs the retention reaper over a modeled sample store.
pub fn prove_retention_reaper(receipt: &ConsentReceipt) -> RetentionProofRuns the retention reaper over a modeled sample store.