pub struct PrivacyReaperProof {
pub hr_evicted: bool,
pub location_evicted: bool,
pub content_evicted: bool,
pub evicted: usize,
}Expand description
Result of the hardware-free privacy reaper proof.
Fields
hr_evicted: boolWhether the HR sample is evicted after the privacy window.
location_evicted: boolWhether the location sample is evicted after the privacy window.
content_evicted: boolWhether referenced content is evicted with the sensitive samples.
evicted: usizeNumber of records evicted by the final sweep.
Implementations