pub struct SerialRealizerRegistry { /* private fields */ }Expand description
Id-addressed registry of serial realizers with stable sorted listing.
Implementations
Sourceimpl SerialRealizerRegistry
impl SerialRealizerRegistry
Sourcepub fn new() -> SerialRealizerRegistry
pub fn new() -> SerialRealizerRegistry
Creates an empty registry.
Sourcepub fn register(
&mut self,
realizer: Arc<dyn SerialRealizer>,
) -> Result<(), RealizerId>
pub fn register( &mut self, realizer: Arc<dyn SerialRealizer>, ) -> Result<(), RealizerId>
Inserts one realizer, rejecting duplicate ids unless the caller uses replace.
Sourcepub fn replace(
&mut self,
realizer: Arc<dyn SerialRealizer>,
) -> Option<Arc<dyn SerialRealizer>>
pub fn replace( &mut self, realizer: Arc<dyn SerialRealizer>, ) -> Option<Arc<dyn SerialRealizer>>
Inserts one realizer and returns the replaced registration, if any.
Sourcepub fn get(&self, id: &RealizerId) -> Option<&Arc<dyn SerialRealizer>>
pub fn get(&self, id: &RealizerId) -> Option<&Arc<dyn SerialRealizer>>
Returns one registered realizer by id.
Sourcepub fn ids(&self) -> Vec<RealizerId>
pub fn ids(&self) -> Vec<RealizerId>
Returns all registered ids in stable sorted order.
Sourcepub fn realize(
&self,
id: &RealizerId,
plan: &SerialPlan,
context: &RealizationContext,
) -> Result<SerialRealization, StrictRealizationError>
pub fn realize( &self, id: &RealizerId, plan: &SerialPlan, context: &RealizationContext, ) -> Result<SerialRealization, StrictRealizationError>
Realizes one plan through the registered realizer named by id.
Sourcepub fn realize_named(
&self,
id: &str,
plan: &SerialPlan,
context: &RealizationContext,
) -> Result<SerialRealization, StrictRealizationError>
pub fn realize_named( &self, id: &str, plan: &SerialPlan, context: &RealizationContext, ) -> Result<SerialRealization, StrictRealizationError>
Realizes one plan through the registered realizer named by a stable string id.