pub struct DoublingAddition {
pub source_event_id: ObjectId,
pub note: StaffNote,
}Expand description
An octave or unison doubling of an existing event.
Fields
source_event_id: ObjectIdExisting event whose onset, duration, and pitch class are doubled.
note: StaffNoteFresh identity-bearing doubling.