pub enum AggregateRuleKind {
ExhaustiveExactlyOnce,
NoRepeat,
DeclaredMultiplicity,
DeclaredOmissions,
ProjectedAggregate,
FreeOrder,
}Expand description
Public category of an AggregateRule.
Variants
ExhaustiveExactlyOnce
Every alphabet symbol occurs exactly once.
NoRepeat
Symbols may be omitted but no symbol may repeat.
DeclaredMultiplicity
Every symbol has an explicitly declared positive multiplicity.
DeclaredOmissions
Every non-omitted symbol occurs exactly once.
ProjectedAggregate
Occurrence requirements apply to declared projection classes.
FreeOrder
Any finite order of alphabet members is accepted, including repeats.