pub enum LengthPolicy {
Exact,
Pad,
Truncate,
}Expand description
Relationship between the logical plan length and available input values.
Variants
Exact
Require exactly the plan length.
Pad
Admit a shorter input and extend it according to PaddingPolicy.
Truncate
Require at least the plan length and ignore later values.