pub struct TransformReport {
pub scratch_bytes: usize,
pub passes: usize,
pub io_blocks: usize,
pub precision: TransformPrecision,
pub plan_digest: ContentId,
}Expand description
Auditable execution facts for an in-memory or blocked transform.
Fields
scratch_bytes: usizePeak temporary storage required by the plan, excluding result storage.
passes: usizeNumber of complete separable axis passes.
io_blocks: usizeTotal Table/Dir blocks read or written.
precision: TransformPrecisionCell representation used for execution.
plan_digest: ContentIdContent digest of shape, axes, conventions, and optional resource plan.