sim-cli 0.3.0
CLI tool for running and comparing Solana simulator backtests
Crate
Builds
Feature flags
Size
Source code size: 273.15 kB
This is the summed size of all the files inside the crates.io package for this release.
Ø build duration
all releases: 1m 17s
Average build duration of
successful
builds in releases after 2024-10-23.
Links
Repository
crates.io
Dependencies
base64 ^0.22.1
normal
chrono ^0.4.41
normal
clap ^4.5.46
normal
console ^0.15
normal
dashmap ^6.1.0
normal
eyre ^0.6.12
normal
flate2 ^1
normal
futures ^0.3.31
normal
indicatif ^0.17.9
normal
rand ^0.9.2
normal
reqwest ^0.12
normal
rustls ^0.23.13
normal
serde ^1.0.219
normal
serde_json ^1.0.143
normal
simulator-api ^0.7.0
normal
simulator-client ^0.7.0
normal
solana-address ^1.0.0
normal
solana-client ^3.1.0
normal
solana-commitment-config ^3.1.0
normal
solana-rpc-client-api ^3.1.0
normal
solana-signature ^3.1.0
normal
solana-transaction-status ^3.1.0
normal
tar ^0.4
normal
tempfile ^3.8
normal
tokio ^1.47.1
normal
tokio-tungstenite ^0.24
normal
tokio-util ^0.7.16
normal
tracing ^0.1.41
normal
tracing-subscriber ^0.3.19
normal
Versions
0.7.0
(2026-06-19)
0.6.0
(2026-06-03)
0.5.1
(2026-05-22)
0.5.0
(2026-05-13)
0.4.0
(2026-05-12)
0.3.0
(2026-04-24)
0.2.0
(2026-04-07)
0.1.0
(2026-04-01)
Owners
sim-cli-0.3.0 is not a library.
Visit the last successful build:
sim-cli-0.7.0