#[sim_codec]Expand description
Marks a codec export inside a #[sim_lib] module. The marker names the
codec symbol plus decoder and encoder functions that are called by generated
native ABI dispatch.
#[sim_codec]Marks a codec export inside a #[sim_lib] module. The marker names the
codec symbol plus decoder and encoder functions that are called by generated
native ABI dispatch.