sim-nest’s product cookbook loadable-lib directory.
sim-lib-cookbook keeps a small standalone fixture directory. The umbrella
crate owns the product directory because only this crate sees the
constellation feature graph without adding back-edges to the cookbook lib.
Structs
- SimNest
Cookbook Resolver - Resolver over the loadable libs linked into this sim-nest build.
Functions
- cookbook_
all_ lib_ ids - Loadable-lib ids compiled into a
cookbook-allbuild. - default_
cookbook_ config - Product default cookbook config for the enabled sim-nest feature set.
- default_
loadable_ libs - Resolve the product default directory for the enabled sim-nest feature set.